@@ -159,6 +159,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
                 if (s.set.placeholder){
                     s.set.placeholder = this['tr'](s.set.placeholder);
                 }
+                if (s.set.label){
+                    s.set.label = this['tr'](s.set.label);
+                }
                 control.set(s.set);
             }
  
